@@ -268,7 +268,7 @@ class ArgoRollout(
         '''
         props = ArgoRolloutProps(metadata=metadata, spec=spec)
 
-        jsii.create(ArgoRollout, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="manifest") # type: ignore[misc]
     @builtins.classmethod
@@ -773,3 +773,6 @@ __all__ = [
 ]
 
 publication.publish()
+
+# Loading modules to ensure their types are registered with the jsii runtime library
+from . import k8s
